/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.storage.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * A Compose request.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Cloud Storage API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ComposeRequest extends GenericJson {

  /**
   * Properties of the resulting object
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private StorageObject destination;

  /**
   * The kind of item this is.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The list of source objects that will be concatenated into a single object.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<SourceObjects> sourceObjects;

  static {
    // hack to force ProGuard to consider SourceObjects used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(SourceObjects.class);
  }

  /**
   * Properties of the resulting object
   * The value returned may be {@code null}.
   */
  public StorageObject getDestination() {
    return destination;
  }

  /**
   * Properties of the resulting object
   * The value set may be {@code null}.
   */
  public ComposeRequest setDestination(StorageObject destination) {
    this.destination = destination;
    return this;
  }

  /**
   * The kind of item this is.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of item this is.
   * The value set may be {@code null}.
   */
  public ComposeRequest setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The list of source objects that will be concatenated into a single object.
   * The value returned may be {@code null}.
   */
  public java.util.List<SourceObjects> getSourceObjects() {
    return sourceObjects;
  }

  /**
   * The list of source objects that will be concatenated into a single object.
   * The value set may be {@code null}.
   */
  public ComposeRequest setSourceObjects(java.util.List<SourceObjects> sourceObjects) {
    this.sourceObjects = sourceObjects;
    return this;
  }

  /**
   * Model definition for ComposeRequestSourceObjects.
   */
  public static final class SourceObjects extends GenericJson {

    /**
     * The generation of this object to use as the source.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long generation;

    /**
     * The source object's name. The source object's bucket is implicitly the destination bucket.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String name;

    /**
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private ObjectPreconditions objectPreconditions;

    /**
     * The generation of this object to use as the source.
     * The value returned may be {@code null}.
     */
    public Long getGeneration() {
      return generation;
    }

    /**
     * The generation of this object to use as the source.
     * The value set may be {@code null}.
     */
    public SourceObjects setGeneration(Long generation) {
      this.generation = generation;
      return this;
    }

    /**
     * The source object's name. The source object's bucket is implicitly the destination bucket.
     * The value returned may be {@code null}.
     */
    public String getName() {
      return name;
    }

    /**
     * The source object's name. The source object's bucket is implicitly the destination bucket.
     * The value set may be {@code null}.
     */
    public SourceObjects setName(String name) {
      this.name = name;
      return this;
    }

    /**

     * The value returned may be {@code null}.
     */
    public ObjectPreconditions getObjectPreconditions() {
      return objectPreconditions;
    }

    /**

     * The value set may be {@code null}.
     */
    public SourceObjects setObjectPreconditions(ObjectPreconditions objectPreconditions) {
      this.objectPreconditions = objectPreconditions;
      return this;
    }

    /**
     * Model definition for ComposeRequestSourceObjectsObjectPreconditions.
     */
    public static final class ObjectPreconditions extends GenericJson {

      /**
       * Only perform the composition if the generation of the source object that would be used matches
       * this value. If this value and a generation are both specified, they must be the same value or
       * the call will fail.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key @JsonString
      private Long ifGenerationMatch;

      /**
       * Only perform the composition if the generation of the source object that would be used matches
       * this value. If this value and a generation are both specified, they must be the same value or
       * the call will fail.
       * The value returned may be {@code null}.
       */
      public Long getIfGenerationMatch() {
        return ifGenerationMatch;
      }

      /**
       * Only perform the composition if the generation of the source object that would be used matches
       * this value. If this value and a generation are both specified, they must be the same value or
       * the call will fail.
       * The value set may be {@code null}.
       */
      public ObjectPreconditions setIfGenerationMatch(Long ifGenerationMatch) {
        this.ifGenerationMatch = ifGenerationMatch;
        return this;
      }

    }
  }

}
